@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2021 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -94,13 +94,11 @@ def get_round_surface(surface, scale_factor, radius):
     height = surface.get_height()
     if isinstance(surface, GdkPixbuf.Pixbuf):
         pixbuf = surface
-        del surface
         width = width // scale_factor
         height = height // scale_factor
         radius = radius // scale_factor
         surface = Gdk.cairo_surface_create_from_pixbuf(
             pixbuf, scale_factor, None)
-        del pixbuf
     rounded = cairo.ImageSurface(cairo.FORMAT_ARGB32, width, height)
     ctx = cairo.Context(rounded)
     degrees = pi / 180
@@ -114,7 +112,6 @@ def get_round_surface(surface, scale_factor, radius):
     ctx.set_source_surface(surface, 0, 0)
     ctx.clip()
     ctx.paint()
-    del surface
     return rounded
 
 
@@ -221,25 +218,6 @@ def get_network_available(acl_name=""):
     return False
 
 
-def do_shift_selection(listbox, row):
-    """
-        Do a shift selection on a listbox
-    """
-    # Get last selected row
-    start_row = None
-    children = listbox.get_children()
-    selected_rows = listbox.get_selected_rows()
-    if selected_rows:
-        start_row = selected_rows[-1]
-    elif children:
-        start_row = children[0]
-    if start_row is not None:
-        start_index = children.index(start_row)
-        end_index = children.index(row)
-        for i in range(start_index, end_index):
-            listbox.select_row(children[i])
-
-
 def noaccents(string):
     """
         Return string without accents lowered
@@ -275,13 +253,18 @@ def escape(str, ignore=["_", "-", " ", "."]):
                     c.isdigit() or c in ignore]).rstrip()
 
 
-def get_lollypop_album_id(name, artists):
+def get_lollypop_album_id(name, artists, year=None):
     """
         Calculate Lollypop album id
         @param name as str
         @param artists as [str]
+        @param year as int/None
     """
-    name = "%s_%s" % (sql_escape(" ".join(artists)), sql_escape(name))
+    if year is None:
+        name = "%s_%s" % (sql_escape(" ".join(artists)), sql_escape(name))
+    else:
+        name = "%s_%s_%s" % (
+            sql_escape(" ".join(artists)), sql_escape(name), year)
     return md5(name.encode("utf-8")).hexdigest()
 
 
@@ -448,6 +431,8 @@ def get_icon_name(object_id):
         icon = "org.gnome.Lollypop-tag-list-symbolic"
     elif object_id == Type.WEB:
         icon = "goa-panel-symbolic"
+    elif object_id == Type.INFO:
+        icon = "dialog-information-symbolic"
     return icon
 
 
@@ -498,8 +483,9 @@ def popup_widget(widget, parent, x, y, state_widget):
         popover.add(widget)
         widget.connect("hidden", on_hidden, popover)
         if state_widget is not None:
-            popover.connect("unmap", on_unmap, state_widget)
-            state_widget.set_state_flags(Gtk.StateFlags.VISITED, False)
+            if not state_widget.get_state_flags() & Gtk.StateFlags.VISITED:
+                popover.connect("unmap", on_unmap, state_widget)
+                state_widget.set_state_flags(Gtk.StateFlags.VISITED, False)
         popover.set_relative_to(parent)
         # Workaround a GTK autoscrolling issue in Gtk.ListBox
         # Gtk autoscroll to last focused widget on popover close
