@@ -19,7 +19,7 @@ from pickle import load, dump
 from lollypop.helper_passwords import PasswordsHelper
 from lollypop.logger import Logger
 from lollypop.utils import get_network_available
-from lollypop.define import LOLLYPOP_DATA_PATH, App, Type
+from lollypop.define import LOLLYPOP_DATA_PATH, App
 from lollypop.define import LASTFM_API_KEY, LASTFM_API_SECRET
 
 
@@ -50,7 +50,7 @@ class LastFMWebService:
             self.__queue = load(
                 open(LOLLYPOP_DATA_PATH + "/%s_queue.bin" % self.__name, "rb"))
         except Exception as e:
-            Logger.info("LastFMWebService::__init__(): %s", e)
+            Logger.info("LastFMWebService::start(): %s", e)
             self.__queue = []
 
     def stop(self):
@@ -73,8 +73,10 @@ class LastFMWebService:
             @param track as Track
             @param timestamp as int
         """
+        monitor = Gio.NetworkMonitor.get_default()
         if App().settings.get_value("disable-scrobbling") or\
-                not get_network_available():
+                not get_network_available() or\
+                monitor.get_network_metered():
             self.__queue.append((track, timestamp))
         elif track.id is not None and track.id >= 0:
             App().task_helper.run(self.__listen, track, timestamp)
@@ -84,8 +86,10 @@ class LastFMWebService:
             Submit a playing now notification for a track
             @param track as Track
         """
+        monitor = Gio.NetworkMonitor.get_default()
         if App().settings.get_value("disable-scrobbling") or\
-                not get_network_available():
+                not get_network_available() or\
+                monitor.get_network_metered():
             return
         if track.id is not None and track.id >= 0:
             App().task_helper.run(self.__playing_now, track)
@@ -201,10 +205,8 @@ class LastFMWebService:
                 if token is None:
                     return
                 args = self.__get_args_for_method("track.scrobble")
-                if track.album.artist_ids[0] == Type.COMPILATIONS:
-                    args.append(("artist", track.artists[0]))
-                else:
-                    args.append(("artist", track.album.artists[0]))
+                args.append(("artist", track.artists[0]))
+                args.append(("albumArtist", track.album.artists[0]))
                 args.append(("track", track.name))
                 args.append(("album", track.album.name))
                 if track.mbid and track.mbid.find(":") == -1:
@@ -224,6 +226,8 @@ class LastFMWebService:
                                                            self.__cancellable)
                 if data is not None:
                     Logger.debug("%s: %s", self.__uri, data)
+                else:
+                    self.__queue.append((track, timestamp))
         except Exception as e:
             Logger.error("LastFMWebService::__listen(): %s" % e)
 
@@ -238,10 +242,8 @@ class LastFMWebService:
             if token is None:
                 return
             args = self.__get_args_for_method("track.updateNowPlaying")
-            if track.album.artist_ids[0] == Type.COMPILATIONS:
-                args.append(("artist", track.artists[0]))
-            else:
-                args.append(("artist", track.album.artists[0]))
+            args.append(("artist", track.artists[0]))
+            args.append(("albumArtist", track.album.artists[0]))
             args.append(("track", track.name))
             args.append(("album", track.album.name))
             if track.mbid and track.mbid.find(":") == -1:
